# luxsci.ServersApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_server_status**](ServersApi.md#get_server_status) | **GET** /account/{accountId}/server/{serverId} | 
[**get_servers**](ServersApi.md#get_servers) | **GET** /account/{accountId}/servers | 
[**server_empty_all_email_queues**](ServersApi.md#server_empty_all_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues/all | 
[**server_empty_email_queues**](ServersApi.md#server_empty_email_queues) | **DELETE** /account/{accountId}/server/{serverId}/sending_queues | 
[**set_server_sendng_rate**](ServersApi.md#set_server_sendng_rate) | **POST** /account/{accountId}/server/{serverId}/sending_rate | 

# **get_server_status**
> InlineResponse20075 get_server_status(account_id, server_id)



This report allows you to retrieve specific current status of a specific server. This request will actually directly interrogate the server for some of this information; in situations where the server is overloaded or down or very slow, *this API will fail.*  {{ACL: Account: Servers - Report}}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ServersApi

account_id = 'account_id_example' # str | 
server_id = 'server_id_example' # str | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.

try:
    api_response = api_instance.get_server_status(account_id, server_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ServersApi->get_server_status: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **server_id** | **str**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

[**InlineResponse20075**](InlineResponse20075.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_servers**
> InlineResponse20074 get_servers(account_id)



This report allows you to retrieve general information about all of the dedicated servers associated with your account. {{ACL: Account: Servers - Report}

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ServersApi

account_id = 'account_id_example' # str | 

try:
    api_response = api_instance.get_servers(account_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ServersApi->get_servers: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 

### Return type

[**InlineResponse20074**](InlineResponse20074.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **server_empty_all_email_queues**
> server_empty_all_email_queues(account_id, server_id)



This command allows you to remove all email messages that are queued.  These are the mail_queue_trying and mail_queue_unprocessed messages returned by the server status call.  Messages that have not yet been processed will be deleted by this call. 

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ServersApi

account_id = 'account_id_example' # str | 
server_id = 'server_id_example' # str | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.

try:
    api_instance.server_empty_all_email_queues(account_id, server_id)
except ApiException as e:
    print("Exception when calling ServersApi->server_empty_all_email_queues: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **server_id** | **str**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **server_empty_email_queues**
> server_empty_email_queues(account_id, server_id)



This command allows you to remove all email messages that are queued and trying to be delivered to recipients.  These are the mail_queue_trying messages returned by the server status call.  Messages that have not yet been processed are not deleted. 

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ServersApi

account_id = 'account_id_example' # str | 
server_id = 'server_id_example' # str | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.

try:
    api_instance.server_empty_email_queues(account_id, server_id)
except ApiException as e:
    print("Exception when calling ServersApi->server_empty_email_queues: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **server_id** | **str**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **set_server_sendng_rate**
> set_server_sendng_rate(account_id, server_id, body=body)



This command allows you to update the email processing rate limits for this server.  These rate limits govern the rate at which messages are processed and delivered to the queues for delivery to recipients, for IP Warmup purposes.  These settings to not impact messages already processed trying to be delivered to recipients.

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.ServersApi

account_id = 'account_id_example' # str | 
server_id = 'server_id_example' # str | Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id.
body = luxsci.ServerIdSendingRateBody() # ServerIdSendingRateBody |  (optional)

try:
    api_instance.set_server_sendng_rate(account_id, server_id, body=body)
except ApiException as e:
    print("Exception when calling ServersApi->set_server_sendng_rate: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **str**|  | 
 **server_id** | **str**| Should be the numeric server_id returned by the Server List API call, above. However, it can also be the short host name. I.e., if server with host rs999 has a server_id of 197890 then you can use either 197890 or 999 as the server_id. | 
 **body** | [**ServerIdSendingRateBody**](ServerIdSendingRateBody.md)|  | [optional] 

### Return type

void (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

